@@ -85,8 +85,7 @@ def install_and_init_agent(token, account_id, custom_host, modules_path):
         create_agent_local_folders()
         handle_base_modules(dirname, modules_path)
         handle_yml_file(dirname)
-        handle_credentials(account_id, script_full_path, spotinst_agent_path, token)
-        handle_custom_host(custom_host)
+        handle_credentials(account_id, script_full_path, spotinst_agent_path, token, custom_host)
         handle_agent_path(spotinst_agent_path)
         runscript = subprocess.Popen(script_full_path)
         runscript.wait()
@@ -146,12 +145,15 @@ def handle_yml_file(dirname):
         copyfile(default_agent_yml, default_yml_destination)
 
 
-def handle_credentials(account_id, script_full_path, spotinst_agent_path, token):
+def handle_credentials(account_id, script_full_path, spotinst_agent_path, token, host):
     if token is not None:
         print ("Creating Spotinst credentials directory")
 
+        if host is None:
+            #if the customer didn't supply custom host set the default
+            host = 'api.spotinst.io'
         creds_file, creds_path = create_creds_file()
-        write_creds_path(account_id, creds_file, token)
+        write_creds_path(account_id, creds_file, token, host)
         os.chmod(creds_path, 0o777)
 
     else:
@@ -159,20 +161,18 @@ def handle_credentials(account_id, script_full_path, spotinst_agent_path, token)
         creds = utils.retrieve_creds()
         token = creds["token"]
         account_id = creds["account_id"]
+        host = creds["host"]
     os.putenv("SPOTINST_TOKEN", token)
     os.putenv("SPOTINST_ACCOUNT_ID", account_id)
+    os.putenv("CUSTOM_HOST", host)
     os.putenv("SPOTINST_AGENT_PATH", spotinst_agent_path)
     os.chmod(script_full_path, 0o777)
 
-def handle_custom_host(custom_host):
-    if custom_host is not None:
-        os.putenv("CUSTOM_HOST", custom_host)
-
-def write_creds_path(account_id, creds_file, token):
+def write_creds_path(account_id, creds_file, token, host):
     if account_id is not None:
-        creds_file.write('token = ' + token + '\n' + 'account_id = ' + account_id)
+        creds_file.write('token = ' + token + '\n' + 'account_id = ' + account_id + '\n' + 'host = ' + host)
     else:
-        creds_file.write('token = ' + token)
+        creds_file.write('token = ' + token + '\n' + 'host = ' + host)
 
 
 def create_creds_file():
