@@ -123,9 +123,8 @@ def init__configuration(config, cloud_provider, debug=False):
     creds = utils.retrieve_creds()
     authentication_token = creds["token"]
     account_id = creds["account_id"]
-    # if the user supply custom host we take it from env variables
-    # else take the default from config file(spotinst-agent.yml)
-    host = os.getenv('CUSTOM_HOST', config['default_host'])
+    host = creds["host"]
+    log.debug("host is {}".format(host))
 
     if cloud_provider.lower() == 'azure':
         instance_details = getAzureInstanceDetails(config, authentication_token, account_id, host, log, debug)
